#
# spec file for package polkit-default-privs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# icecream 0


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           polkit-default-privs
Version:        1550+20241017.007e12d
Release:        1.1
Summary:        SUSE PolicyKit default permissions
License:        GPL-2.0-or-later
Group:          Productivity/Security
Source:         polkit-default-privs-%version.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Supplements:    PolicyKit
Supplements:    libpolkit0
BuildRequires:  polkit
Requires(pre):  polkit
Supplements:    polkit
BuildArch:      noarch
# please open bugreports at bugzilla.suse.com
URL:            http://github.com/openSUSE/polkit-default-privs.git
PreReq:         %fillup_prereq

%description
Predefined polkit profiles for different usage scenarios like desktop and
server. These profiles define the kind of authentication required for various
polkit actions used across applications.

%prep
%setup -q

%build

%install
make install DESTDIR=$RPM_BUILD_ROOT fillupdir="%{_fillupdir}"
mkdir -p $RPM_BUILD_ROOT/etc/polkit-1/rules.d/
> $RPM_BUILD_ROOT/etc/polkit-1/rules.d/90-default-privs.rules

%post
%{fillup_only -ns security polkit_default_privs}
/usr/sbin/set_polkit_default_privs >/dev/null

%files
%define basedir %{_distconfdir}/polkit-default-privs
%define profiledir %{basedir}/profiles
%define confdir /etc/polkit-1
%doc README.md
%ghost %attr(0644,root,root) %{confdir}/rules.d/90-default-privs.rules
%dir %{basedir}
%dir %{profiledir}
%{profiledir}/easy
%{profiledir}/standard
%{profiledir}/restrictive
%{basedir}/local.template
/usr/sbin/chkstat-polkit
/usr/sbin/set_polkit_default_privs
%_mandir/man*/*
%{_fillupdir}/sysconfig.security-polkit_default_privs

%changelog
* Thu Oct 17 2024 matthias.gerstner@suse.com
- Update to version 1550+20241017.007e12d:
  * profiles: whitelist additional kinfocenter action (bsc#1231659)
  * Update rule for kpmcore (bsc#1203315)
* Tue Jul  9 2024 filippo.bonazzi@suse.com
- Update to version 1550+20240708.7e0e3f4:
  * profile: whitelist kdeplasma-addons-kameleon helper (bsc#1226306)
* Thu Jun 20 2024 filippo.bonazzi@suse.com
- Update to version 1550+20240620.095c860:
  * profiles: add powerdevil conservation mode actions (bsc#1226424)
* Wed Jun 19 2024 wolfgang.frisch@suse.com
- Update to version 1550+20240619.190ee11:
  * profiles: whitelist drkonqi6 (bsc#1220190)
* Thu Jun 13 2024 filippo.bonazzi@suse.com
- Update to version 1550+20240613.b3a8db7:
  * whitelist new systemd methods (bsc#1225317)
* Wed May 22 2024 wolfgang.frisch@suse.com
- Update to version 1550+20240522.4ba9229:
  * whitelist gnome-remote-desktop (bsc#1222159)
* Tue Apr 30 2024 wolfgang.frisch@suse.com
- Update to version 1550+20240430.5327266:
  * profiles: whitelist dnf5daemon-server (bsc#1218327)
  * profiles: remove pseudo auth action kcmkwallet5 (bsc#1217190)
* Mon Mar 25 2024 wolfgang.frisch@suse.com
- Update to version 1550+20240325.eddbe04:
  * profiles: power-profiles-daemon (bsc#1219957)
* Mon Mar 11 2024 wolfgang.frisch@suse.com
- Update to version 1550+20240311.559e6ac:
  * whitelist gnome-control-center remote-session-helper (bsc#1220862)
* Thu Mar  7 2024 filippo.bonazzi@suse.com
- Update to version 1550+20240307.987ebab:
  * add incremental libvirt addition org.libvirt.api.node-device.save (bsc#1221094)
* Fri Feb 23 2024 filippo.bonazzi@suse.com
- Update to version 1550+20240223.b0857d7:
  * profiles: add new tuned actions (bsc#1220081)
* Wed Feb  7 2024 wolfgang.frisch@suse.com
- Update to version 1550+20240207.d833f4b:
  * profiles: remove no longer used device-rebind action
* Wed Dec 13 2023 filippo.bonazzi@suse.com
- Update to version 1550+20231213.09963a4:
  * profiles: add and adjust polkit actions for gamemode (bsc#1217915)
* Wed Nov 29 2023 wolfgang.frisch@suse.com
- Update to version 1550+20231129.269abcd:
  * profiles: whitelist cinnamon-settings-daemon wacom-oled-helper (bsc#1217532)
* Fri Nov  3 2023 filippo.bonazzi@suse.com
- Update to version 1550+20231103.3b4a82f:
  * profiles: fwupd: add host-security-attr actions (bsc#1216832)
  * profiles: remove outdates sysprof2 actions
  * profiles: drop obsolete udisks2 bcache and zram actions
* Fri Oct  6 2023 filippo.bonazzi@suse.com
- Update to version 1550+20231006.28f05f1:
  * Whitelist policycoreutils-dbus actions (bsc#1213435)
* Wed Sep 20 2023 wolfgang.frisch@suse.com
- Update to version 1550+20230920.74aeded:
  * udisks2: add additional NVME action (bsc#1214897)
* Tue Sep 12 2023 wolfgang.frisch@suse.com
- Update to version 1550+20230912.0978001:
  * udisks2: add additional mount and NVME actions (bsc#1214897)
* Tue Aug 29 2023 filippo.bonazzi@suse.com
- Update to version 1550+20230829.1a9a761:
  * deepin-api: provide backward compatibility whitelisting (bsc#1214101)
* Tue Jun  6 2023 wolfgang.frisch@suse.com
- Update to version 1550+20230606.5001571:
  * Whitelist org.freedesktop.systemd1.bypass-dump-ratelimit (bsc#1211978)
* Fri Jun  2 2023 matthias.gerstner@suse.com
- Update to version 1550+20230602.0c9c3c6:
  * profiles: drop dead mousepad action
* Wed May 17 2023 matthias.gerstner@suse.com
- Update to version 1550+20230517.ab68b2d:
  * rename com.deepin.api to org.deepin.dde (bsc#1211376)
* Tue Mar  7 2023 wolfgang.frisch@suse.com
- Update to version 1550+20230307.7f42172:
  * Whitelist kde-inotify-survey (bsc#1208689)
* Fri Mar  3 2023 matthias.gerstner@suse.com
- Update to version 1550+20230303.7726e9f:
  * tuned: incremental addition of new acquire_devices method (bsc#1208727)
* Wed Nov  2 2022 matthias.gerstner@suse.com
- Update to version 1550+20221102.9f111fa:
  * allow local logged in users to change NetworkManager configuration,
    keyboard layout and locale settings without entering a password (in the
    easy profile).
* Tue Oct 18 2022 matthias.gerstner@suse.com
- Update to version 1550+20221018.7616c25:
  * fwupd (bsc#1204026): add incremental {get,set}-bios-settings
* Mon Sep 19 2022 matthias.gerstner@suse.com
- adjust spec file to deal with /sbin -> /usr/sbin path change
- Update to version 1550+20220919.3b55a1f:
  * kdiskmark: adjust to new major version action renaming (bsc#1202725)
  * Use /usr/sbin nowadays (boo#1191090)
* Tue Aug  2 2022 matthias.gerstner@suse.com
- Update to version 1550+20220727.3ce2e2f:
  * iio-sensor-proxy (bsc#1201558): add claim-sensor action
* Wed Jun  8 2022 wolfgang.frisch@suse.com
- Update to version 1550+20220608.097448e:
  * Whitelist new systemd methods (bsc#1200098)
* Tue May 24 2022 wolfgang.frisch@suse.com
- Update to version 1550+20220524.0345bd9:
  * Add kinfocenter5 whitelisting (bsc#1199735).
  * gconf: cleanup rules used by dropped gconf2 package
* Mon Apr  4 2022 filippo.bonazzi@suse.com
- Update to version 1550+20220404.7b4bea2:
  * Add whitelisting to restrictive profile as well
  * Add budgie-control-center whitelisting (bsc#1195023)
* Fri Apr  1 2022 matthias.gerstner@suse.com
- Update to version 1550+20220401.41ccb1d:
  * usbguard: relax read-only operations to yes
* Fri Mar 25 2022 matthias.gerstner@suse.com
- Update to version 1550+20220325.163dbdf:
  * whitelisting: add usbguard actions (bsc#1196621)
* Thu Mar 24 2022 matthias.gerstner@suse.com
- Update to version 1550+20220324.7f46822:
  * Fix generation of file /etc/polkit-1/rules.d/90-default-privs.rules
* Thu Mar  3 2022 matthias.gerstner@suse.com
- Update to version 1550+20220303.95a78fb:
  * kpmcore: whitelist block device (re-)partioning helper (bsc#1178848)
* Fri Feb 25 2022 matthias.gerstner@suse.com
- Update to version 1550+20220225.330e064:
  * Whitelist Kcron (bsc#1193945)
  * deepin-api: drop manage-locale action that is not package on openSUSE
  * udisks2: remove manage-vdo action
* Tue Dec 14 2021 wolfgang.frisch@suse.com
- Update to version 1550+20211214.daf2765:
  * fwupd: tighten the downgrade rules (bsc#1193310)
* Thu Dec  9 2021 wolfgang.frisch@suse.com
- Update to version 1550+20211209.8ce206c:
  * fwupd: whitelist new, more granular permissions (bsc#1193310)
* Fri Nov 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Change Requires: polkit to Requires(pre): we need to be sure
  polkit is instaled first, as we could otherwise end up with wrong
  permissions on /etc/polkit-1/rules.d.
* Fri Nov 19 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- remove traces of old polkit-whitelisting sub-package
* Fri Oct  8 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- drop backward compatibility symlink in /etc/polkit-default-privs.standard.
  rpmlint 2.0 is now in Factory and the check there directly uses the profile
  in /usr/etc/polkit-default-privs/profiles/standard.
- drop polkit-whitelisting sub-package. This is now handled in rpmlint 2.0
  internally.
* Fri Oct  8 2021 matthias.gerstner@suse.com
- Update to version 1550+20211008.9751669:
  * whitelist power-profiles-daemon actions (bsc#1189900)
  * cleanup: remove polkit-rules-whitelist.json
* Wed Aug 18 2021 matthias.gerstner@suse.com
- Update to version 1550+20210818.b0c41fd:
  * whitelist deepin-api service actions (bsc#1070943)
* Fri Aug 13 2021 matthias.gerstner@suse.com
- Update to version 1550+20210813.ce0df56:
  * malcontent: loosen restrictive ReadOwn actions to prevent spurious auth requests (#56)
* Thu Jul 22 2021 matthias.gerstner@suse.com
- Update to version 1550+20210722.ae1891d:
  * whitelist zypp-gui action (bsc#1188364)
  * introduce sub-directories for profiles in both /etc and /usr/etc
  * remove polkit-default-privs.d package specific directory
  * Moving polkit-default-privs.easy, polkit-default-privs.local and polkit-default-privs.restrictive from /etc /to /usr/etc directory
* Thu Jul 15 2021 wolfgang.frisch@suse.com
- Update to version 1550+20210715.b7d5b97:
  * kdenetwork-filesharing: tighten the restrictive profile
* Wed Jul 14 2021 wolfgang.frisch@suse.com
- Update to version 1550+20210714.9c51c0e:
  * 50-default.rules: move to /usr (contents unchanged)
  See also: https://build.opensuse.org/request/show/905083
* Thu Jul  8 2021 wolfgang.frisch@suse.com
- Update to version 1550+20210708.6401347:
  * fprint.device.enroll: keep restrictive profile in sync with upstream
* Thu Jul  8 2021 wolfgang.frisch@suse.com
- Update to version 1550+20210708.c4d6bf4:
  * kdenetwork-filesharing: align with upstream (#49)
* Thu Jul  8 2021 wolfgang.frisch@suse.com
- Update to version 1550+20210701.3047fcb:
  * ModemManager1.USSD: fix inconsistencies in standard and easy profiles
  * powerdevil.discretegpuhelper.hasdualgpu: align with upstream settings
  * cupspkhelper.mechanism.job-edit: align with upstream setting
  * org.fedoraproject.FirewallD1.info: don't be more restrictive than the 'standard' profile
  * remove org.selinux.* (policycoreutils) since they no longer exist in Factory
  * remove cinnamon.controlcenter.datetime.configure: no longer packaged
  * net.connman.vpn.secret: fix invalid label "auth_admin_keep_session"
* Tue Jun 15 2021 wolfgang.frisch@suse.com
- Update to version 1550+20210615.e149f78:
  * profiles: cinnamon-settings-daemon (bsc#1186845)
* Thu Jun 10 2021 jsegitz@suse.com
- Update to version 1550+20210610.25c9b98:
  * Whitelist setroubleshoot (boo#1186344)
* Thu May 20 2021 matthias.gerstner@suse.com
- Update to version 1550+20210520.336dcea:
  * whitelist incremental libvirt org.libvirt.api.node-device.delete (bsc#1186270)
* Mon May 17 2021 paolo.perego@suse.com
- Update to version 1550+20210517.56da22d:
  * Add systemd homed (boo#1185285)
* Mon May  3 2021 matthias.gerstner@suse.com
- Update to version 1550+20210503.88baaca:
  * whitelist deepin-system-monitor pkexec actions (bsc#1181886)
* Fri Apr 30 2021 matthias.gerstner@suse.com
- Update to version 1550+20210430.c408cda:
  * systemd: add newly added inhibit-handle-reboot-key action (bsc#1185468)
  * whitelist non-functional change in systemd-networkd rules (bsc#1185469)
* Thu Apr 29 2021 matthias.gerstner@suse.com
- Update to version 1550+20210429.a605b7d:
  * tuned: whitelist incrementally added polkit action (bsc#1185418)
* Mon Apr 12 2021 wolfgang.frisch@suse.com
- Update to version 1550+20210409.c29362e:
  * profiles: add KDiskMark (bsc#1182521)
  * profiles: add kdenetwork-filesharing (bsc#1175633) (#37)
* Mon Jan 11 2021 matthias.gerstner@suse.com
- Update to version 1550+20210111.f725c25:
  * polkit-rules-whitelist: add brltty brlapi group rule (bsc#1180593)
* Tue Dec  8 2020 matthias.gerstner@suse.com
- Update to version 1550+20201208.135bf51:
  * libvirt: allow the active session to create read-only connections (bsc#1179126)
  * profiles: cleanup outdates keep_always entries
* Thu Nov 19 2020 matthias.gerstner@suse.com
- Update to version 1550+20201119.2c1dce4:
  - cleanup of dead and inconsistent polkit actions:
  * profiles: drop the now rather confusing comment from nwfilter-binding actions
  * profiles: harmonize and normalize profile syntax and style
  * profiles: harmonize spice-space.lowlevelusbaccess actions
  * profiles: remove dead pantheon actions
  * profiles: remove dead org.gnome.DejaDup.duplicity action
  * profiles: drop dead com.redhat.tuned.gui.run action
  * profiles: fix brltty action(s)
  * profiles: remove dead netvisix action
  * profiles: realmd.discover-realm action: fix restrictive any setting
  * profiles: remove dead com.redhat.lvm2.* actions
  * profiles: group together org.kde.powerdevil actions
  * profiles: remove dead org.kde.powerdevil.backlighthelper actions
  * profiles: fix FirewallD1.info action in standard profile
  * profiles: remove dead org.kde.baloo action
  * profiles: remove dead kwallet actions and fix kwallet5 restrictive setting
  * profiles: selinux actions: make restrictive profile no weaker than upstream
  * profiles: remove dead gufw pkexec action
  * profiles: adjust mate actions better to upstream defaults
  * profiles: remove dead org.libvirt.api.newfilter.bind-* actions
  * profiles: clear dead nepomuk.filewatch.raiselimit action
  * profiles: remove dead kcmlightdm actions
  * profiles: adjust gnome.controlcenter actions better to upstream defaults
  * profiles: remove dead org.kde.recorditnow helper
  * profiles: remove dead de.berlios.smb4k.mounthelper actions
  * profiles: adjust user-administration action better to upstream defaults
  * profiles: cleanup urfkill actions
  * profiles: adjust ModemManager1 actions better to upstream settings
  * profiles: cleanup ModemManager actions
  * profiles: sync hp.driveguard.* actions with upstream settings
  * profiles: gnome settings, xfce backlight-helper actions: sanitize settings
  * profiles: cleanup dead and sync existing org.gnome actions
  * profiles: sync timedate1 actions in restrictive profile with standard profile
  * profiles: remove dead sytemd1.bus-access action
  * profiles: remove dead org.kde actions
  * profiles: make org.kde settings no weaker than upstream settings
  * profiles: remove leftover dead yast actions
  * profiles: remove dead yast.modules.yapi actions
  * profiles: remove dead yast.modules.ysr actions
  * profiles: remove dead yast.modules actions
  * profiles: remove dead yast.module-manager and yast.scr actions
  * profiles: remove dead upower actions
  * profiles: add missing udisks2 actions in restrictive profile
  * profiles: remove dead udisks (1) actions
  * profiles: remove dead policykit.lockdown action, harmonize .exec setting
  * profiles: adjust RealtimeKit actions to upstream settings
  * profiles: remove dead SuSEfirewall2 zone switcher action
  * profiles: remove dead backupmanager action
  * profiles: remove dead smpppd action
  * profiles: remove dead consolekit actions
  * profiles: polkit example action run-frobnicate: adjust to upstream settings
  * profiles: remove dead org.gnome.policykit.examples.* actions
  * profiles: remove unused pulseaudio realtime actions
  * profiles: cleanup PackageKit actions
  * profiles: cleanup gnome-settings-daemon actions
  * profiles: cleanup network manager actions
  * profiles: cleanup outdated PolicyKit actions
* Tue Nov  3 2020 matthias.gerstner@suse.com
- Update to version 1550+20201103.994a5ed:
  * udisks2: rename of manage-led action to match upstream changes (bsc#1178321)
* Mon Nov  2 2020 matthias.gerstner@suse.com
- Update to version 1550+20201030.d1b5d8b:
  * whitelisting of GNOME malcontent parental controls (bsc#1177974)
  * restrictive profile: fix conflicting duplicate action org.kde.powerdevil.backlighthelper.setbrightness
  * restrictive profile: fix conflicting duplicate action org.freedesktop.color-manager.delete-profile
  * profiles: fix conflicting duplicate action org.kde.powerdevil.backlighthelper.brightness
  * profiles: remove duplicate actions with same authentication settings
  * tools: new script to cleanly remove duplicate actions
* Mon Oct 19 2020 matthias.gerstner@suse.com
- Update to version 1550+20201012.1df5a0d:
  * whitelist new plasma5-disks smartmon helper (bsc#1176742)
* Thu Oct  1 2020 matthias.gerstner@suse.com
- Update to version 1550+20201001.cb7020b:
  * Whitelist newly added powerdevil battery charge threshold actions (bsc#1176474)
* Thu Sep 10 2020 matthias.gerstner@suse.com
- Update to version 1550+20200909.647e56f:
  * whitelist org.freedesktop.network1.forcerenew (bsc#1176215)
* Wed Jul 15 2020 matthias.gerstner@suse.com
- Update to version 1550+20200715.6ddc764:
  * whitelist libvirt-dbus rule file (bsc#1173093)
* Tue Jun 30 2020 jsegitz@suse.com
- Update to version 1550+20200630.e9f182b:
  * whitelist io.veyon.pkexec.veyon-configurator (bsc#1172318)
* Wed May 20 2020 jsegitz@suse.de
- Update to version 1550+20200520.d0dc67f:
  * whitelist org.cockpit-project.cockpit.root-bridge (bsc#1169614)
* Mon Apr 20 2020 matthias.gerstner@suse.com
- Update to version 1550+20200417.940923e:
  * packagekit: allow system-sources-refresh w/o password entry (bsc#1169540)
* Wed Mar 25 2020 malte.kraus@suse.com
- Update to version 1550+20200325.f1362c4:
  * whitelist chvt action in logind (bsc#1167542)
* Tue Mar 10 2020 matthias.gerstner@suse.com
- Update to version 1550+20200310.cdde967:
  * profiles: whitelist new timeshift pkexec actions (bsc#1165436)
  * polkit profile: remove trailing '###' lines
* Fri Feb 28 2020 Johannes Segitz <jsegitz@suse.de>
- Going back to old versioning scheme as only %%suse_version doesn't
  carry enough information. Keeping the git hash would be enough,
  but with that we can't ensure that versions increase. So we keep
  also the timestamp and prefix it with the current %%suse_version
* Wed Feb 19 2020 Johannes Segitz <jsegitz@suse.de>
- Change the package version to match %%suse_version. The current
  versioning was obviously based on this at one time. Dropping date
  and git commit information since it's meaningless.
- Removed author information from the description
- Removed conditional Requires: for libmozjs185-1_0 for old
  distributions
* Thu Feb 13 2020 matthias.gerstner@suse.com
- Update to version 13.2+20200213.f716f0a:
  * Revert "whitelist lutris (bsc#1161650)"
* Thu Feb  6 2020 matthias.gerstner@suse.com
- Update to version 13.2+20200206.331ac1d:
  * whitelist lutris (bsc#1161650)
* Tue Jan 21 2020 matthias.gerstner@suse.com
- Update to version 13.2+20200121.bfca858:
  * systemd networkd incremental polkit rules (bsc#1161328)
* Thu Jan 16 2020 jsegitz@suse.de
- Update to version 13.2+20200116.0f7fd4b:
  * Previous submission didn't contain all necessary files (bsc#1161091)
* Thu Jan 16 2020 jsegitz@suse.de
- Update to version 13.2+20200116.3c654b5:
  * flatpak: Add additional entry to whitelist to reflect added
    override-parental-controls entry (bsc#1161091)
* Thu Jan 16 2020 malte.kraus@suse.com
- Update to version 13.2+20200116.c29a8c3:
  * whitelist new sysprof3 polkit rule org.gnome.sysprof3.profile
    (bsc#1151418)
* Tue Dec 10 2019 matthias.gerstner@suse.com
- Update to version 13.2+20191210.15c9882:
  * polkit-rules-whitelist: adjust whitelist format to new rpmlint-checks logic
* Thu Nov 28 2019 malte.kraus@suse.com
- Update to version 13.2+20191128.c2eb3f7:
  * fix ModemManager1.Time whitelisting (bsc#1156961)
* Fri Nov 22 2019 malte.kraus@suse.com
- Update to version 13.2+20191122.eb9cc80:
  * whitelist org.freedesktop.ModemManager1.Modem.Time (bsc#1156961)
* Tue Nov 19 2019 matthias.gerstner@suse.com
- Update to version 13.2+20191119.a36b458:
  * kcm_sddm: incremental addition of new rules (bsc#1145182)
* Tue Oct 15 2019 jsegitz@suse.de
- Update to version 13.2+20191015.280c25b:
  * gnome-initial-session: whitelist polkit rules in
    20-gnome-initial-setup.rules (bsc#1125432)
* Mon Oct 14 2019 malte.kraus@suse.com
- Update to version 13.2+20191014.aad0cdf:
  * Networkd package actually ended up beeing called
    "sytemd-network" (#11, boo#1153885)
* Thu Sep 19 2019 jsegitz@suse.de
- Update to version 13.2+20190919.a656be4:
  * transition networkd rules to subpackage
* Thu Sep  5 2019 malte.kraus@suse.com
- Update to version 13.2+20190905.0016c47:
  * whitelist new systemd-resolved actions (bnc#1149216)
* Tue Aug 27 2019 malte.kraus@suse.com
- Update to version 13.2+20190827.0cc2a82:
  * make new systemd rules more restrictive (boo#1146300,
    boo#1145639)
* Fri Aug 23 2019 lnussel@suse.de
- Update to version 13.2+20190823.a5f89c3:
  * systemd-networkd (boo#1146300)
  * systemd-portabled (boo#1145639)
* Tue Aug  6 2019 jsegitz@suse.de
- Update to version 13.2+20190806.841a06b:
  * libvirt polkit actions: Additional no:no:no action (bsc#1144077)
* Thu Aug  1 2019 matthias.gerstner@suse.com
- Update to version 13.2+20190801.f0c6234:
  * calamares: whitelist pkexec run as root in X11 action
  * mousepad: whitelisting of pkexec action (bsc#1143216)
* Thu Jul 11 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190711.953db4f:
  * libvirt: add a couple of additional polkit actions (bsc#1140151)
* Thu Jul  4 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190704.dfb36ad:
  * libvirt rules: fix whitelisting (bsc#1125314)
* Wed Jul  3 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190703.9a076dc:
  * libvirt polkit actions: whitelisting of incremental no:no:no actions (bsc#1140151)
  * backintime-qt: removal of old rule name (bsc#1133680)
* Mon May 27 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190527.64d9813:
  * polkit-rules-whitelist.json: fix syntax error
* Thu May 23 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190523.efe368f:
  * polkit profiles: whitelist lightdm-gtk-greeter-settings (bsc#1135695)
* Mon May 20 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190520.a67a2af:
  * polkit rules: whitelist libvirt (bsc#1125314)
  * rules for systemd org.freedesktop.login1.set-reboot* (bsc#1133843)
* Tue May  7 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190507.75c6d67:
  * fwupd: add one more follow-up rules for bsc#1133082
* Fri May  3 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190503.00651e7:
  * tuned: add new plugin doc actions (bsc#1131858)
* Thu May  2 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190502.37ad64c:
  * fwupd: add incrementally added polkit actions (bsc#1133082)
* Tue Apr 30 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190430.a4836d6:
  * backintime: add renamed gui pkexec action (bsc#1133680)
  * backintime: add restrictive config, too
* Thu Apr 11 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190411.5775d58:
  * gamemode: additional polkit action for gpuclockctl (bsc#1129967)
  * NetworkManager: remove wrongly named wifi-scan rule (bsc#1128560)
* Fri Mar 15 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190315.3da47ba:
  * rules.d whitelist: add systemd-network (bsc#1125438) and flatpak entries (bsc#984817)
* Fri Mar 15 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190315.b904805:
  * polkit privs whitelisting: add renamed wifi-scan -> wifi.scan action (bsc#1128560)
* Wed Mar  6 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190306.b56445c:
  * whitelisting: systemd org.freedesktop.hostname1.get-product-uuid
* Tue Feb 26 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190226.f884108:
  * polkit-rules-whitelist: adjust format to better support follow-up audits
    (bsc#1125314)
* Mon Feb 25 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190225.0ef150d:
  * relax change-own-user-data action in the restrictive profile (bsc#1125110)
* Wed Feb 13 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190213.2f39f9b:
  * add whitelisting file for files installed in polkit-1/rules.d * (bsc#1125314)
  * the new whitelisting is packaged in a separate subpackage, because it is
    not needed for normal operation, only during OBS build time for rpmlint to
    find it.
* Thu Feb  7 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190207.4d86620:
  * add manage-vdo privilege of udisks2 (bsc#1123747)
  * further improve documentation in /etc/polkit-default-privs.local
  * sort the output rules in /etc/polkit-1/rules.d/90-default-privs to
    make the runs reproducible. (https://github.com/openSUSE/polkit-default-privs/issues/3)
* Wed Feb  6 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190207.9bb8655:
  * man pages: extend documentation to better describe syntax and profiles
  * install README.md as part of package documentation
  * set_polkit_default_privs: add warning about unknown profiles
  * introduce a new polkit-default-privs easy profile
* Wed Jan 30 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190130.b2262b2:
  * Whitelist additional Flatpak action metadata-update (bsc#1123653)
  * soften authentication requirements for flatpak's appstream-update (bsc#1122116)
* Mon Jan 28 2019 opensuse-packaging@opensuse.org
- whitelist newly introduced network manager wifi-scan action (bsc#1122262)
* Fri Jan 25 2019 bjorn.lie@gmail.com
- Be explicit in service file about master branch is the one in use
  for tarball generation via revision parameter.
* Mon Jan 14 2019 matthias.gerstner@suse.com
- introduce service file for pulling new releases from git upstream instead of
  using the old mkchanges script from the git repo (bsc#1121841). This changes
  the version number of the package but nothing else.
* Thu Jan  3 2019 matthias.gerstner@suse.com
- luckybackup: initial whitelisting of polkit pkexec action (bsc#1120403)
* Fri Dec 21 2018 matthias.gerstner@suse.com
- boltd: initial whitelisting of polkit actions (bsc#1119975)
* Tue Dec 11 2018 matthias.gerstner@suse.com
- tuned: add new logging actions (bsc#1118117)
* Tue Nov 27 2018 matthias.gerstner@suse.com
- chkstat: adjust DO NOT EDIT banner in generated rules file (bsc#1099754)
* Thu Nov 15 2018 matthias.gerstner@suse.com
- spice-gtk: relax lowlevelusbaccess requirements (bsc#1083025). Users already
  need to be in the kvm group to access the setuid binary anyways.
* Thu Nov 15 2018 matthias.gerstner@suse.com
- blueman: relax standard profile rules, drop unneeded bluez.config rule (bsc#1083066)
* Wed Sep  5 2018 matthias.gerstner@suse.com
- polkit-default-privs: add renamed libvirt rules (bsc#1106813)
* Thu Aug  9 2018 matthias.gerstner@suse.com
- polkit-default-privs: add meson install action (bsc#1103811)
* Wed Aug  8 2018 matthias.gerstner@suse.com
- polkit-default-privs: fix syntax error in gamemode whitelisting (bsc#1104135)
* Mon Jul 30 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelist gamemode pkexec action (bsc#1093979)
* Fri Jul 27 2018 matthias.gerstner@suse.com
- polkit-default-privs: fix switchboard-plug* whitelisting. An error slipped
  in that causes `set_polkit_default_privs` to print an error message.
* Fri Jul  6 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelist incremental libvirt actions (bnc#1100328)
- polkit-default-privs: group together the large blocks of libvirt rules
* Thu Jul  5 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelist switchboard-plug-* (bsc#1088472)
* Fri Jun 22 2018 matthias.gerstner@suse.com
- polkit-default-privs: add cinnamon-control-center datetime action (bnc#1090371)
* Thu Jun 21 2018 matthias.gerstner@suse.com
- polkit-default-privs: add lightdm rules (bnc#1089436)
* Wed Jun 13 2018 matthias.gerstner@suse.com
- polkit-default-privs: added liblxqt backlight action (bnc#1092192)
* Tue Jun 12 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelisting new resolve1 action of systemd (bnc#1096907)
- polkit-default-privs: harmonized systemd comments a bit
* Thu Jun  7 2018 matthias.gerstner@suse.com
- polkit-default-privs: new action change-own-password for accountsservice (bnc#1088780)
* Tue Apr 24 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelisting renamed kalarm polkit actions (bnc#1087714)
* Wed Apr 11 2018 matthias.gerstner@suse.com
- polkit-default-privs: additional tuned rules (bnc#1088648)
* Wed Mar 28 2018 matthias.gerstner@suse.com
- polkit-default-privs: some more amnesty whitelisting of untracked
  privileges. Two more packages are affected:
  - bleachbit (bsc#1087326)
  - systemd, systemd-mini (bsc#1087328)
* Mon Mar 12 2018 matthias.gerstner@suse.com
- polkit-default-privs: mass amnesty whitelisting of untracked privileges. See
  https://lists.opensuse.org/opensuse-factory/2018-02/msg01044.html for
  rationale. This allows existing packages in Factory to continue building
  after the tighter rpmlint-Factory checks become effective. Following
  packages are affected:
  - blueman (bsc#1083066)
  - cinnamon settings-daemon (bnc#1083067)
  - connman (bsc#1083069)
  - flatpak (bsc#984817)
  - fwupd (bsc#1083022)
  - gsmartcontrol (bsc#1084693)
  - gvfs (bsc#1073214)
  - laptop-mode-tools (bsc#1084695)
  - mate-system-monitor (bsc#1084701)
  - nemo (bsc#1084702)
  - nemo-extensions (bsc#1084703)
  - PackageKit (bnc#993505)
  - pantheon-files (bsc#1084704)
  - scap-workbench (bsc#1084706)
  - spice-gtk (bsc#1083025)
  - sysprof (bsc#1083055)
* Wed Jan 31 2018 krahmer@suse.com
- polkit-default-privs: adding more NM actions (bsc#1077504)
* Wed Jan 17 2018 krahmer@suse.com
- polkit-default-privs: adding new udisks2 rules (bsc#1073216)
* Mon Dec 18 2017 matthias.gerstner@suse.com
- polkit-default-privs: added connectivity-check for NetworkManager (bnc#1072702)
* Wed Nov 29 2017 krahmer@suse.com
- polkit-default-privs: adding new sddm kcm actions (bsc#1065563)
* Fri Nov 24 2017 matthias.gerstner@suse.com
- Fixed usage of %%_fillupdir macro, needs to be passed to `make install` such
  that the file is installed into the right location.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Oct 25 2017 krahmer@suse.com
- polkit-default-privs: adding flatpak (bsc#1064011)
- polkit-default-privs: adding connman (bsc#1057697)
* Wed Oct 11 2017 krahmer@suse.com
- polkit-default-privs: adding deja-dup (bsc#1058935)
* Wed Sep  6 2017 krahmer@suse.com
- polkit-default-privs: adding fwupd (bsc#932807)
* Wed Aug 23 2017 krahmer@suse.com
- adding more flatpak rules (bsc#1012961)
* Fri Jul 21 2017 matthias.gerstner@suse.com
- Added new tuned method verify_profile_ignore_missing (bnc#1048961)
* Wed Jul 19 2017 krahmer@suse.com
- polkit-default-privs: adding new realmd action (bsc#1048025)
* Mon Jul  3 2017 krahmer@suse.com
- polkit-default-privs: adjusting brltty (bsc#967436)
* Tue Jun 20 2017 krahmer@suse.com
- relaxing action "org.opensuse.cupspkhelper.mechanism.job-edit" (bsc#827331)
* Fri Apr 28 2017 matthias.gerstner@suse.com
- added polkit rules for backintime (bnc#1007723, bnc#1032717)
- relaxing powerdevil rules (bsc#1026038)
* Tue Apr 11 2017 matthias.gerstner@suse.com
- added polkit rules for renamed kcmwallet -> kcmwallet5 (bsc#1033296)
* Tue Apr 11 2017 matthias.gerstner@suse.com
- added polkit rules for tuned (bsc#1007279)
* Mon Feb  6 2017 krahmer@suse.com
- polkit-default-privs: adding blueman actions (bsc#987141)
* Mon Jan 30 2017 krahmer@suse.com
- adding kde powerdevil gpu helper (bsc#1019644)
* Tue Dec  6 2016 krahmer@suse.com
- adding org.freedesktop.login1.set-self-linger (bsc#1009468)
* Tue Oct 11 2016 meissner@suse.com
- add flatpak privileges, but currently auth_admin currently (bsc#984817)
* Mon Sep 12 2016 krahmer@suse.com
- polkit-default-privs: cleanups as per discussion with Ludwig
- polkit-default-privs: adding rules for sysprof (bsc#996111) and networkmanager (bsc#996110)
* Mon Jun 13 2016 krahmer@suse.com
- polkit-default-privs: adding ModemManager (bsc#976945)
* Wed Apr 13 2016 krahmer@suse.com
- added brltty (bsc#967436)
* Mon Apr 11 2016 meissner@suse.com
- add importd privs as default tracked (bsc#964935)
* Tue Mar 22 2016 krahmer@suse.com
- polkit-default-privs: relaxing firewalld polkit rule for desktop (bsc#971580)
* Tue Jan  5 2016 krahmer@suse.com
- polkit-default-privs: adding libvirt action ids (bsc#959297)
* Tue Dec  1 2015 krahmer@suse.com
- polkit-default-privs: Adding new systemd actions (bsc#955626)
- polkit-default-privs: create files with consistent permissions
* Mon Nov  9 2015 krahmer@suse.com
- polkit-default-privs: adding rules for cinnamon settings-daemon (bsc#951830)
- polkit-default-privs: relaxing some ModemManager rules to avoid typing password after screenlock/hibernate (bsc#948728)
* Tue Jun 23 2015 krahmer@suse.com
- polkit-default-privs: PackageKit (bnc#929212)
* Mon Jun  8 2015 krahmer@suse.com
- polkit-default-privs: adding netvisix rules (bsc#930195)
* Fri May 22 2015 meissner@suse.com
- instead of auth-admin, disallow colord management for inactive and
  other users, so they do not get root password popups bsc#918594
* Wed Apr 22 2015 krahmer@suse.com
- polkit-default-privs: adding gnome-control-center actions (bnc#927508)
    adding realmd actions (bnc#916767)
* Mon Apr 20 2015 krahmer@suse.com
- polkit-default-privs: rename of powerdevil action-names (bnc#927275)
* Wed Apr  8 2015 krahmer@suse.com
- polkit-default-privs: add urfkill (bnc#926288) polkit action
* Tue Apr  7 2015 krahmer@suse.com
- polkit-default-privs: added gnome-multi-writer actions (bnc#924062)
* Wed Feb 11 2015 krahmer@suse.com
- adding storaged rules (bnc#915770)
* Wed Jan 14 2015 krahmer@suse.com
- adding KDE5 powerdevil rules (bnc#912121)
* Wed Dec 10 2014 krahmer@suse.com
- added firewalld (bnc#907625) polkit actions
* Fri Nov 28 2014 krahmer@suse.com
- polkit-default-privs: adding _keep to ModemManager rules (bnc#900813)
* Fri Nov  7 2014 meissner@suse.com
- Add org.kde.kcontrol.kcmsddm.save (bsc#904313)
* Mon Nov  3 2014 krahmer@suse.com
- polkit-default-privs: relaxing pcsc rules (bsc#864178)
* Mon Sep 29 2014 krahmer@suse.com
- polkit-default-privs: Addings missing rules for restrictive mode (bnc#898001)
* Wed Aug  6 2014 krahmer@suse.com
- polkit-defaultprivs: relaxing rules for SLE12 create-profile in colord (bnc#887511)
* Tue Jul 15 2014 krahmer@suse.com
- relaxing fprintd rules (bnc#850807)
* Fri Jul 11 2014 meissner@suse.com
- replace SuSEconfig mentioning by correct script name (bnc#886809)
* Mon May 19 2014 meissner@suse.com
- tentatively allow new org.selinux helper interfaces in policycoreutils (bnc#878631)
- polkit-default-privs: adding pcsc-lite rules (bnc#864178)
* Wed Apr 16 2014 meissner@suse.com
- change org.kde.fontinst.manage to auth_admin_keep (bnc#704805)
* Wed Apr 16 2014 meissner@suse.com
- adding org.kde.baloo.filewatch.raiselimit action (bnc#866131)
* Mon Mar 24 2014 krahmer@suse.com
- polkit-default-privs: relaxing
  org.freedesktop.color-manager.create-device   and
  org.freedesktop.color-manager.delete-device, its basically just a DB
  operation and colord checks the owner of delete id is the same as
  the creator (bnc#861076)
* Wed Mar 12 2014 meissner@suse.com
- backlight helpers: relaxing rules in restrictive mode,
  otherwise we get popups requesting LED state changes
  bnc#866806
* Wed Nov 20 2013 krahmer@suse.com
- Adding kwallet polkit rules (bnc#849739)
* Tue Nov 19 2013 meissner@suse.com
- new version is 13.2
* Tue Nov 19 2013 krahmer@suse.com
- adding policycoreutils rules (bnc#848550)
* Tue Oct 29 2013 meissner@suse.com
- git repo moved to https://github.com/openSUSE/polkit-default-privs
* Wed Oct 23 2013 meissner@suse.com
- disable system source refresh on inactive console to avoid annoying popups bnc#834165
* Wed Aug 28 2013 meissner@suse.com
- allow org.mate.power.backlight-helper on standard (bnc#831404)
- track gufw
- add org.mate.randr.install-system-wide auth_admin_keep (bnc#831404)
- track mate-settings-daemons privileges (bnc#831404)
* Wed Jul 10 2013 meissner@suse.com
- added polkit-default-privs temporary permissions until audited bnc#827644
* Fri Jul  5 2013 dimstar@opensuse.org
- Only require libmozjs185-1_0 on openSUSE up to 12.3:
  + On openSUSE 13.1, we use libmozjs-17_0
  + Since polkit 0.111, the mozjs library parser is no longer
    optional. For this reason, we also do not have to worry to
    Require the correct library in this case anymore.
* Thu Jul  4 2013 meissner@suse.com
- added powerdevil privs (bnc#825256)
* Fri Jun 28 2013 meissner@suse.com
- Added gnome-settings-daemon new policy
  org.gnome.settings-daemon.plugins.wacom.wacom-oled-helper (bnc#822405)
* Mon Jun 17 2013 meissner@suse.com
- track nepomuk rights (bnc#825262)
* Fri Jun 14 2013 meissner@suse.com
- gnome-system-monitor: track its permissions as they are found (bnc#822011)
* Tue Jun 11 2013 meissner@suse.com
- added lightdm-kde-greeter (bnc#794705)
* Tue Jun  4 2013 meissner@suse.com
- allow fprintd polkit privileges (bnc#792095)
* Mon Apr 15 2013 meissner@suse.com
- ModemManager 0.8 with org.freedesktop.ModemManager1 interface added (a bit more relaxed than the old interface) bnc#798273
- 13.1 is next opensuse
* Wed Apr  3 2013 meissner@suse.com
- bump version for next openSUSE release.
* Wed Apr  3 2013 meissner@suse.com
- allow org.freedesktop.packagekit.trigger-offline-update and org.freedesktop.packagekit.clear-offline-update in standard same way as normal patch update (bnc#798885 bnc#812504)
* Wed Mar 27 2013 meissner@suse.com
- added new udisks2 privileges (bnc#809277)
* Fri Mar 22 2013 meissner@suse.com
- add org.opensuse.policykit.gparted auth_admin (bnc#810888)
* Sun Mar 10 2013 hrvoje.senjan@gmail.com
- Default rules are moved to '90', so own them as '90' instead '50'
* Tue Mar  5 2013 lnussel@suse.de
- move default rules to '90', bnc#807097
* Wed Feb 27 2013 lnussel@suse.de
- add /etc/polkit-1/rules.d/50-default-privs.rules as ghost so it
  gets associated with the package
* Wed Feb 27 2013 lnussel@suse.de
- require ibmozjs185-1_0 as polkit won't apply the policy without it
  (bnc#804376)
* Tue Feb 26 2013 lnussel@suse.de
- set logind inhibit policies to upstream defaults (bnc#804376)
- more elaborate --check-override option
* Mon Feb 25 2013 lnussel@suse.de
- add some debugging capabilities in generated code
* Sat Feb 23 2013 coolo@suse.com
- do not own the polkit directories (with different user, creating
  conflict), but buildrequire polkit
* Thu Feb 21 2013 lnussel@suse.de
- fix restrictive privileges
- generate javascript files for new polkit (bnc#804376)
- implement check for overrides
* Tue Feb 19 2013 meissner@suse.com
- whitelist PackageKit / systemd offline update permissions, currently admin only
- more systemd allows to make rpmlint happier bnc#783897
* Fri Nov  2 2012 meissner@suse.com
- new systemd privileges, mostly allowing applications to inhibit system actions (bnc#783897)
* Wed Oct 24 2012 meissner@suse.com
- added polkit default privs for GNOME control-center (bnc#779938)
* Tue Oct 23 2012 meissner@suse.com
- added new udisks2 policykit privileges at lowest setting bnc#779404
* Tue Oct 16 2012 meissner@suse.com
- 12.3 is next opensuse
* Tue Oct 16 2012 meissner@suse.com
- allow realtimekit at desktop permission (bnc#753849)
- fixed typo
* Thu Jul 12 2012 meissner@suse.com
- allow logged in users to update the system via online updates. bnc#771189
* Thu Jul  5 2012 meissner@suse.com
- relax colord after auditing (bnc#698250)
* Tue Jun  5 2012 lnussel@suse.de
- fix script name in sysconfig file (bnc#765227)
* Tue May 15 2012 lnussel@suse.de
- add more udisks2 privileges (bnc#761872)
* Thu Mar 29 2012 lnussel@suse.de
- add org.kde.recorditnow.helper.watch (bnc#753908)
- add org.gnome.settings-daemon.plugins.wacom.wacom-led-helper (bnc#750795)
* Wed Feb 29 2012 lnussel@suse.de
- add smb4k (bnc#749065)
* Wed Feb 29 2012 lnussel@suse.de
- add udisks2 (bnc#742751)
* Wed Jan 18 2012 lnussel@suse.de
- add org.freedesktop.packagekit.repair-system (bnc#742024)
- fix FSF address
- remove old obsoletes
* Thu Dec  1 2011 lnussel@suse.de
- add org.opensuse.yast.system.terminal.read
* Wed Nov 23 2011 lnussel@suse.de
- set version to 12.2
- remove obsolete moblin privileges
- allow org.freedesktop.ModemManager.Device.Control (bnc#732358)
- allow setting the system's time zone (bnc#731812)
* Wed Nov 23 2011 lnussel@suse.de
- change NetworkManager policies (bnc#716291)
* Fri Oct 28 2011 lnussel@suse.de
- fix logind privileges to be consistend with consolekit (bnc#726969)
* Wed Oct 26 2011 lnussel@suse.de
- set org.freedesktop.accounts.change-own-user-data to yes (bnc#676638)
* Tue Aug 23 2011 lnussel@suse.de
- rename gnome backlight-helper privilege (bnc#712841)
* Fri Aug  5 2011 lnussel@suse.de
- add org.kde.kalarmrtcwake.settimer (bnc#707723)
* Thu Jul 28 2011 lnussel@suse.de
- set NetworkManager.settings.modify.{own,system} to auth_admin_keep
  so it's less annoying (bnc#680140)
- silence %%post  (bnc#679336)
* Thu Jul 28 2011 lnussel@suse.de
- more sytemd/logind privileges (bnc#641924)
* Wed Jul 27 2011 lnussel@suse.de
- change inactive backlight helper privileges to 'no' (bnc#708639)
- remove hal privileges
* Thu Jul 21 2011 lnussel@suse.de
- change version to 12.1 to show that the package is tied to the
  distro
- set org.freedesktop.accounts.user-administration to auth_admin_keep
* Thu Jul 14 2011 lnussel@suse.de
- add more systemd privileges (bnc#705677)
* Thu Jul  7 2011 lnussel@suse.de
- set org.gnome.gconf.defaults.* to auth_admin_keep (bnc#703582)
* Thu Jun 16 2011 lnussel@suse.de
- add colord (bnc#698250)
* Mon May 16 2011 lnussel@suse.de
- webyast shutdown privs (bnc#687807)
* Thu May  5 2011 lnussel@suse.de
- add org.freedesktop.ModemManager.USSD (bnc#691896)
* Thu May  5 2011 lnussel@suse.de
- more systemd stuff (bnc#641924)
* Mon May  2 2011 lnussel@suse.de
- add NetworkManager.settings.modify.hostname (bnc#680140)
- add account services (bnc#676638)
- add org.opensuse.cupspkhelper.mechanism.all-edit (bnc#691014)
* Thu Apr 28 2011 lnussel@suse.de
- new gnome-settings-daemon settings (bnc#690496)
* Tue Apr 26 2011 lnussel@suse.de
- add urfkill (bnc#688328)
* Wed Mar 16 2011 lnussel@suse.de
- add some new NetworkManager privileges (bnc#680140)
* Mon Mar  7 2011 lnussel@suse.de
- allow org.freedesktop.ModemManager.Device.Info for active user
  (bnc#674022)
* Tue Feb 15 2011 lnussel@suse.de
- add kde backlight helper (bnc#672145)
* Tue Feb 15 2011 lnussel@suse.de
- add webyast network module (bnc#660981)
* Mon Feb 14 2011 lnussel@suse.de
- more webyast
* Tue Feb  8 2011 lnussel@suse.de
- add webyast-base-ws (bnc#660981)
* Tue Feb  8 2011 lnussel@suse.de
- don't set PolicyKit privileges if PolicyKit isn't installed (bnc#670155)
* Wed Jan 26 2011 lnussel@suse.de
- allow setting the backlight without authentication (bnc#650401)
* Fri Jan 21 2011 lnussel@suse.de
- add xfce4-power-manager (bnc#665169)
* Wed Dec 15 2010 lnussel@suse.de
- add org.freedesktop.packagekit.upgrade-system (bnc#659384)
* Wed Nov 24 2010 lnussel@suse.de
- add policies that appeared in Factory
* Tue Oct 19 2010 lnussel@suse.de
- add policies that appeared in Factory
* Tue Sep 21 2010 lnussel@suse.de
- use unix-group instead of unix-user for polkit-1 overrides (bnc#544579)
* Fri Aug  6 2010 lnussel@suse.de
- add org.kde.kcontrol.kcmkdm
- change org.gnome.clockapplet.mechanism
  - > org.gnome.settingsdaemon.datetimemechanism (bnc#629096)
* Thu Jun 17 2010 lnussel@suse.de
- change org.opensuse.cupspkhelper.mechanism.* to auth_admin_keep (bnc#614779)
* Tue Apr  6 2010 lnussel@suse.de
- add policies that appeared in Factory
* Thu Apr  1 2010 lnussel@suse.de
- add policies that appeared in Factory
- remove PolicyKit requirement
* Fri Mar 26 2010 lnussel@suse.de
- add policies that appeared in Factory
* Thu Feb 25 2010 lnussel@suse.de
- add policies that appeared in Factory
* Thu Oct 22 2009 lnussel@suse.de
- allow users to set the drive spindown time (bnc#548858)
* Tue Oct  6 2009 lnussel@suse.de
- add YaST privileges from Factory
- add org.freedesktop.devicekit.disks.drive-set-spindown which
  appeared in Factory. Sounds potentially dangerous so auth_admin.
* Wed Sep 23 2009 lnussel@suse.de
- own directories in /var (bnc#541258)
* Fri Aug 28 2009 lnussel@suse.de
- polkit-1 support
- add new policies from Factory
* Thu Jan 29 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Dec 11 2008 lnussel@suse.de
- PreReq on PolicyKit to avoid errors from %%post
* Thu Dec 11 2008 lnussel@suse.de
- add privileges silently indroduced by new hal:
    org.freedesktop.hal.device-access.removable-block
    org.freedesktop.hal.leds.brightness
* Tue Nov 25 2008 lnussel@suse.de
- add missing cupspkhelper privileges
* Thu Nov 20 2008 lnussel@suse.de
- com.google.code.backupmanager.schedule -> org.opensuse.backupmanager.schedule
* Tue Nov  4 2008 lnussel@suse.de
- correct comment for POLKIT_DEFAULT_PRIVS (bnc#441300)
* Tue Oct 28 2008 lnussel@suse.de
- add system-config-printer and a few more hal device access lines
* Mon Oct 27 2008 lnussel@suse.de
- combine privilege settings from multiple files (bnc#439127)
* Fri Oct 24 2008 lnussel@suse.de
- fix some wrong privilege settings (bnc#435776)
  * smpppd.connect, system-update and settimezone in restrictive
  * settimezone in standard
* Mon Oct  6 2008 dmueller@suse.de
- obsolete resmgr and hal-resmgr for openSUSE 11.1 and newer
* Wed Sep 17 2008 lnussel@suse.de
- add manpages
- do not use SuSEconfig
* Tue Sep 16 2008 lnussel@suse.de
- add COPYING file (bnc#425444)
- add privilege for backup-manager
* Thu Sep 11 2008 lnussel@suse.de
- allow setting the sytem timezone and installing updates by default
- add smpppd
* Thu Sep  4 2008 lnussel@suse.de
- rename to polkit-default-privs
- add sysconfig files
- default levels are "standard" and "restrictive"
* Tue Aug 19 2008 lnussel@suse.de
- add device access, consolekit, packagekit.set-proxy
* Fri Jun 20 2008 lnussel@suse.de
- add program to list permissions that are missing
- add a few more programs that have permissions
* Wed Jun 18 2008 lnussel@suse.de
- fix easy permissions
- print message when changing permissions
- add libvirt
* Thu Jun 12 2008 lnussel@suse.de
- fix SuSEconfig.polkit-permissions
* Thu Jun 12 2008 lnussel@suse.de
- initial package
